@@ -8,6 +8,6 @@
 #' @seealso \code{\link{grid}},\code{\link{gridExtra}}
 #' @importFrom gtable gtable_add_grob gtable_add_rows gtable_add_padding gtable_add_cols
 #' @importFrom gridExtra tableGrob ttheme_minimal
-#' 
-function()
-  NULL
+#' @name forestploter-package
+#' @docType package
+"_PACKAGE"
