@@ -26,7 +26,8 @@ dt$Placebo <- ifelse(is.na(dt$Placebo), "", dt$Placebo)
 dt$se <- (log(dt$hi) - log(dt$est))/1.96
 
 # Add blank column for the forest plot to display CI.
-# Adjust the column width with space. 
+# Adjust the column width with space, increase number of space below 
+# to have a larger area to draw the CI. 
 dt$` ` <- paste(rep(" ", 20), collapse = " ")
 
 # Create confidence interval column to display
@@ -140,8 +141,9 @@ p <- forest(dt[,c(1:3, 8:9)],
 plot(p)
 
 
-## ----multiple-group, out.width="80%", fig.width  = 8, fig.height = 6.5--------
+## ----multiple-group, out.width="80%", fig.width  = 8, fig.height = 5----------
 dt <- read.csv(system.file("extdata", "example_data.csv", package = "forestploter"))
+dt <- dt[1:7, ]
 # indent the subgroup if there is a number in the placebo column
 dt$Subgroup <- ifelse(is.na(dt$Placebo), 
                       dt$Subgroup,
@@ -155,6 +157,17 @@ dt$n2 <- ifelse(is.na(dt$Placebo), "", dt$Placebo)
 dt$`CVD outcome` <- paste(rep(" ", 20), collapse = " ")
 dt$`COPD outcome` <- paste(rep(" ", 20), collapse = " ")
 
+# Generate point estimation and 95% CI. Paste two CIs together and separate by line break.
+dt$ci1 <- paste(sprintf("%.1f (%.1f, %.1f)", dt$est_gp1, dt$low_gp1, dt$hi_gp1),
+                sprintf("%.1f (%.1f, %.1f)", dt$est_gp3, dt$low_gp3, dt$hi_gp3),
+                sep = "\n")
+dt$ci1[grepl("NA", dt$ci1)] <- "" # Any NA to blank
+
+dt$ci2 <- paste(sprintf("%.1f (%.1f, %.1f)", dt$est_gp2, dt$low_gp2, dt$hi_gp2),
+                sprintf("%.1f (%.1f, %.1f)", dt$est_gp4, dt$low_gp4, dt$hi_gp4),
+                sep = "\n")
+dt$ci2[grepl("NA", dt$ci2)] <- ""
+
 # Set-up theme
 tm <- forest_theme(base_size = 10,
                    refline_lty = "solid",
@@ -164,9 +177,11 @@ tm <- forest_theme(base_size = 10,
                    legend_name = "Group",
                    legend_value = c("Trt 1", "Trt 2"),
                    vertline_lty = c("dashed", "dotted"),
-                   vertline_col = c("#d6604d", "#bababa"))
+                   vertline_col = c("#d6604d", "#bababa"),
+                   # Table cell padding, width 4 and heights 3
+                   core = list(padding = unit(c(4, 3), "mm")))
 
-p <- forest(dt[,c(1, 19, 21, 20, 22)],
+p <- forest(dt[,c(1, 19, 23, 21, 20, 24, 22)],
             est = list(dt$est_gp1,
                        dt$est_gp2,
                        dt$est_gp3,
@@ -179,10 +194,10 @@ p <- forest(dt[,c(1, 19, 21, 20, 22)],
                          dt$hi_gp2,
                          dt$hi_gp3,
                          dt$hi_gp4),
-            ci_column = c(3, 5),
+            ci_column = c(4, 7),
             ref_line = 1,
             vert_line = c(0.5, 2),
-            nudge_y = 0.2,
+            nudge_y = 0.4,
             theme = tm)
 
 plot(p)
@@ -219,6 +234,45 @@ p <- forest(dt[,c(1, 21, 23, 22, 24)],
 
 plot(p)
 
+## ----custom-ci, out.width="70%", fig.width  = 3, fig.height = 3---------------
+# Function to calculate Box plot values
+box_func <- function(x){
+  iqr <- IQR(x)
+  q3 <- quantile(x, probs = c(0.25, 0.5, 0.75), names = FALSE)
+  c("min" = q3[1] - 1.5*iqr, "q1" = q3[1], "med" = q3[2],
+    "q3" = q3[3], "max" = q3[3] + 1.5*iqr)
+}
+# Prepare data
+val <- split(ToothGrowth$len, list(ToothGrowth$supp, ToothGrowth$dose))
+val <- lapply(val, box_func)
+
+dat <- do.call(rbind, val)
+dat <- data.frame(Dose = row.names(dat),
+                  dat, row.names = NULL)
+
+dat$Box <- paste(rep(" ", 20), collapse = " ")
+
+# Draw single group box plot
+tm <- forest_theme(ci_Theight = 0.2)
+
+p <- forest(dat[,c(1, 7)],
+            est = dat$med,
+            lower = dat$min,
+            upper = dat$max,
+            # sizes = sizes,
+            fn_ci = make_boxplot,
+            ci_column = 2,
+            lowhinge = dat$q1, 
+            uphinge = dat$q3,
+            hinge_height = 0.2,
+            # values of the lowhinge and uphinge will be used as row values
+            index_args = c("lowhinge", "uphinge"), 
+            gp_box = gpar(fill = "black", alpha = 0.4),
+            theme = tm
+)
+p
+
+
 ## ----eval=FALSE---------------------------------------------------------------
 #  # Base method
 #  png('rplot.png', res = 300, width = 7.5, height = 7.5, units = "in")
